netapp_ontap.models.file API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.file`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

You can use the ONTAP DCN cluster software upload API to upload the DCN software image from the local system to the ONTAP cluster.

### Uploading a software package

The following example shows how to upload a DCN software package.

    # The API:
    /api/dcn/cluster/software/upload
    # The call:
    curl -ku username:password -F "file=@auDev__aidp_dcn_image.tgz__2c9ca354-0ff6-4041-aa71-df76eadaba9e.tgz" -X POST "https://<mgmt-ip>/api/dcn/cluster/software/upload"
    # The response:
    HTTP/1.1 100 Continue
    HTTP/1.1 200 OK
    {
          "uuid": "f0ce5ac2-3347-4fa9-9335-ff8f2212bdad",
          "state": "processing",
          "create_time": "2025-07-09T13:27:09-04:00"
    }

## Classes

`class FileSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the File object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `path: str GET POST PATCH`

    Path of the file or directory.

  `svm: Svm GET POST PATCH`

    The svm field of the file.

  `volume: Volume GET POST PATCH`

    The volume field of the file.